@@ -148,6 +148,9 @@ class DisplaySubMenuItem(BrowserSubMenuItem):
 
     @memoize
     def available(self):
+        if self.disabled():
+            return False
+
         isDefaultPage = self.context_state.is_default_page()
 
         folder = None
@@ -293,7 +296,7 @@ class DisplayMenu(BrowserMenu):
                              'action'      : None,
                              'selected'    : True,
                              'icon'        : None,
-                             'extra'       : {'id': '_folderDefaultPageDisplay', 'separator': 'actionSeparator', 'class': ''},
+                             'extra'       : {'id': '_folderDefaultPageDisplay', 'separator': 'actionSeparator', 'class': 'actionMenuSelected'},
                              'submenu'     : None,
                              })
             # Let the user change the selection
@@ -473,8 +476,7 @@ class FactoriesSubMenuItem(BrowserSubMenuItem):
     @memoize
     def _itemsToAdd(self):
         context=self.context_state.folder()
-        return [(context, fti)
-                for fti in self._addableTypesInContext(self.context_state.folder())]
+        return [(context, fti) for fti in self._addableTypesInContext(context)]
 
     def _addableTypesInContext(self, addContext):
         allowed_types = _allowedTypes(self.request, addContext)
